@@ -91,15 +91,15 @@ public:
 	typedef	short	Sample;
 	typedef	short	*Linear;
 	typedef	short	Level;
-	typedef	unsigned short bin16_t;
-	typedef unsigned long bin32_t;
 	typedef	DWORD	timeout_t;
+	typedef	WORD	snd16_t;
+	typedef	DWORD	snd32_t;
 #else
+	typedef	int16_t snd16_t;
+	typedef	int32_t	snd32_t;
 	typedef	int16_t	Level;
 	typedef	int16_t	Sample;
 	typedef	int16_t	*Linear;
-	typedef	uint16_t	bin16_t;
-	typedef	uint32_t	bin32_t;
 	typedef	unsigned long	timeout_t;
 #endif
 
@@ -332,6 +332,64 @@ public:
 	static bool loadPlugin(const char *path);
 };
 
+/**
+ * The AudioTone class is used to create a frame of audio encoded single or
+ * dualtones.  The frame will be iterated for each request, so a
+ * continual tone can be extracted by frame.
+ *
+ * @author David Sugar <dyfet@ostel.com>
+ * @short audio tone generator class.
+ */
+class __EXPORT AudioTone : public Audio
+{
+private:
+	Rate rate;
+	unsigned samples;
+	Linear frame;
+	double df1, df2, p1, p2;
+	Level m1, m2;
+
+public:
+	inline Rate getRate(void)
+		{return rate;};
+
+	inline size_t getSamples(void)
+		{return samples;};
+
+	/**
+	 * Iterate the tone frame, and extract linear samples in
+	 * native frame.  If endian flag passed, then convert for
+	 * standard endian representation (byte swap) if needed.
+	 *
+	 * @return pointer to samples.
+	 */
+	Linear getFrame(bool endian = false);	
+
+	/**
+	 * Construct a dual tone frame generator.
+	 *
+	 * @param freq of tone 1.
+	 * @param freq of tone 2.
+	 * @param level of tone 1.
+	 * @param level of tone 2.
+	 * @param duration of frame in milliseconds.
+	 * @param sample rate being generated.
+	 */
+	AudioTone(unsigned freq1, unsigned freq2, Level l1, Level l2, timeout_t duration = 20, Rate r = rate8khz);
+
+	/**
+	 * Construct a single tone frame generator.
+	 *
+	 * @param freq of tone.
+	 * @param level of tone.
+	 * @param duration of frame in milliseconds.
+	 * @param sample rate being generated.
+	 */
+	AudioTone(unsigned freq, Level l, timeout_t duration = 20, Rate r = rate8khz); 
+
+	~AudioTone();
+};
+
 /**
  * The AudioBuffer class is for mixing one-to-one
  * soft joins.
@@ -447,23 +505,22 @@ protected:
 	const char * getErrorStr(Error err);
 	Error setError(Error err);
 
-	unsigned long getHeader(void)
+	inline unsigned long getHeader(void)
 		{return header;};
 
-	bin16_t getShort(unsigned char *data);
-	void setShort(unsigned char *data, bin16_t value);
-	bin32_t getLong(unsigned char *data);
-	void setLong(unsigned char *data, bin32_t value);
+	unsigned short getShort(unsigned char *data);
+	void setShort(unsigned char *data, unsigned short value);
+	unsigned long getLong(unsigned char *data);
+	void setLong(unsigned char *data, unsigned long value);
 
 public:
 	AudioFile(const char *fname, unsigned long samples = 0);
 	AudioFile(const char *fname, Info *info, unsigned long min = 0);
 
-	AudioFile()
+	inline AudioFile()
 		{initialize();};
 
-	virtual ~AudioFile()
-		{clear();};
+	virtual ~AudioFile();
 
 	/**
 	 * Open an audio file and associate it with this object.
