@@ -87,8 +87,10 @@ AudioCodec *AudioFile::getCodec(void)
 	}
 }
 
-void AudioFile::setShort(unsigned char *data, bin16_t val)
+void AudioFile::setShort(unsigned char *data, unsigned short sval)
 {
+	snd16_t val = (snd16_t)sval;
+
 	if(info.order == __BIG_ENDIAN)
 	{
 		data[0] = val / 256;
@@ -101,7 +103,7 @@ void AudioFile::setShort(unsigned char *data, bin16_t val)
 	}
 }
 
-Audio::bin16_t AudioFile::getShort(unsigned char *data)
+unsigned short AudioFile::getShort(unsigned char *data)
 {
 	if(info.order == __BIG_ENDIAN)
 		return data[0] * 256 + data[1];
@@ -109,9 +111,10 @@ Audio::bin16_t AudioFile::getShort(unsigned char *data)
 		return data[1] * 256 + data[0];
 }
 
-void AudioFile::setLong(unsigned char *data, bin32_t val)
+void AudioFile::setLong(unsigned char *data, unsigned long lval)
 {
 	int i = 4;
+	snd32_t val = (snd32_t)lval;
 
 	while(i-- > 0)
 	{
@@ -123,10 +126,10 @@ void AudioFile::setLong(unsigned char *data, bin32_t val)
 	}
 }
 
-Audio::bin32_t AudioFile::getLong(unsigned char * data)
+unsigned long AudioFile::getLong(unsigned char * data)
 {
 	int i = 4;
-	bin32_t val =0;
+	unsigned long val =0;
 
 	while(i-- > 0)
 	{
@@ -160,6 +163,11 @@ AudioFile::AudioFile(const char *name, Info *info, unsigned long samples)
 	setMinimum(samples);
 }
 
+AudioFile::~AudioFile()
+{
+	AudioFile::close();
+}
+
 void AudioFile::create(const char *name, Info *myinfo, bool exclusive, timeout_t framing)
 {
 	int pcm = 0;
@@ -371,8 +379,8 @@ void AudioFile::create(const char *name, Info *myinfo, bool exclusive, timeout_t
 		else
 			setShort(riffhdr + 10, 2);
 		setLong(riffhdr + 12, info.rate);
-		setLong(riffhdr + 16, toBytes(info, info.rate));
-		setShort(riffhdr + 20, (bin16_t)toBytes(info, 1));
+		setLong(riffhdr + 16, (unsigned long)toBytes(info, info.rate));
+		setShort(riffhdr + 20, (snd16_t)toBytes(info, 1));
 		setShort(riffhdr + 22, 0);
 
 		switch(info.encoding)
@@ -856,7 +864,7 @@ done:
 	if(mode == modeFeed)
 	{
 		setPosition();
-		iolimit = toBytes(info, getPosition());
+		iolimit = (unsigned long)toBytes(info, getPosition());
 		setPosition(0);
 	}
 }
@@ -894,7 +902,7 @@ void Audio::Info::setFraming(timeout_t timeout)
 
 	framing = timeout;
 	framecount = (rate * framing) / 1000l;
-	framesize = toBytes(encoding, framecount);
+	framesize = (unsigned)toBytes(encoding, framecount);
 };
 
 void Audio::Info::set(void)
@@ -1034,7 +1042,7 @@ unsigned AudioFile::getLinear(Linear addr, unsigned samples)
 
 	count = getCount(info.encoding);
 	samples = (samples / count) * count;
-	count = toBytes(info, samples);
+	count = (int)toBytes(info, samples);
 
 	char *buffer = new char[count];
 	count = getBuffer(buffer, count);
@@ -1068,7 +1076,7 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 
 	count = getCount(info.encoding);
 	samples = samples / count * count;
-	count = toBytes(info, samples);
+	count = (int)toBytes(info, samples);
 
 	char *buffer = new char[count];
 
@@ -1078,7 +1086,7 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 		delete[] buffer;
 		return 0;
 	}
-	count = toBytes(info, samples);
+	count = (int)toBytes(info, samples);
 	count = putBuffer(buffer, count);
 	delete[] buffer;
 	if(count < 0)
@@ -1092,9 +1100,10 @@ int AudioFile::getBuffer(void *addr, unsigned bytes)
 	Info prior;
 	char *fname;
 	unsigned char *caddr = (unsigned char *)addr;
-	int count, curpos, xfer = 0;
+	int count;
+	unsigned long curpos, xfer = 0;
 
-        curpos = toBytes(info, getPosition());
+    curpos = (unsigned long)toBytes(info, getPosition());
 	if(curpos >= iolimit && mode == modeFeed)
 	{
 		curpos = 0;
@@ -1157,10 +1166,10 @@ Audio::Error AudioFile::getSamples(void *addr, unsigned request)
 {
 	char *fname;
 	unsigned char *caddr = (unsigned char *)addr;
-	int count;
+	int count, bytes;
 	for(;;)
 	{
-		int bytes = toBytes(info, request);
+		bytes = (int)toBytes(info, request);
 		if(bytes < 1)
 			return setError(errRequestInvalid);
 		count = afRead(caddr, bytes);
@@ -1215,7 +1224,7 @@ int AudioFile::putBuffer(void *addr, unsigned len)
 	int count;
 	unsigned long curpos;
 
-	curpos = toBytes(info, getPosition());
+	curpos = (unsigned long)toBytes(info, getPosition());
         if(curpos >= iolimit && mode == modeFeed)
         {
                 curpos = 0;
@@ -1244,7 +1253,7 @@ int AudioFile::putBuffer(void *addr, unsigned len)
 Audio::Error AudioFile::putSamples(void *addr, unsigned samples)
 {
 	int count;
-	int bytes = toBytes(info, samples);
+	int bytes = (int)toBytes(info, samples);
 	if(bytes < 1)
 		return setError(errRequestInvalid);
 
@@ -1287,7 +1296,7 @@ Audio::Error AudioFile::setLimit(unsigned long samples)
 	}
 
 	samples += getPosition();
-	iolimit = toBytes(info, samples);
+	iolimit = (unsigned long)toBytes(info, samples);
 	return errSuccess;
 }
 
