@@ -48,6 +48,20 @@
 #define	M_PI	3.14159265358979323846
 #endif
 
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#if defined(_WIN64) 
+#define	RLL_SUFFIX ".x64"
+#elif defined(_M_IX86)
+#define	RLL_SUFFIX ".x86"
+#else
+#define RLL_SUFFIX ".xlo"
+#endif
+#endif
+
+#if !defined(RLL_SUFFIX) && defined(W32)  && !defined(__MINGW32__) && !defined(__CYGWIN32__)
+#define	RLL_SUFFIX ".rll"
+#endif
+
 static ccAudio_Mutex_ lock;
 
 #if defined(HAVE_PTHREAD_H)
@@ -167,7 +181,7 @@ bool AudioCodec::load(const char *name)
 	char path[256];
 	bool success = true;
 
-#ifdef	WIN32
+#ifdef	RLL_SUFFIX
 	char fn[16];
 	char *p = fn;
 	char *q = fn;
@@ -181,13 +195,17 @@ bool AudioCodec::load(const char *name)
 		++p;
 	}
 	*q = 0;
-	len = strlen(fn);
-	snprintf(fn + len, sizeof(fn) - len, ".rll");
+	len = (unsigned)strlen(fn);
+	snprintf(fn + len, sizeof(fn) - len, RLL_SUFFIX);
 	name = fn;
 
 	snprintf(path, sizeof(path), "%s/%s", Audio::getCodecPath(), name);
 #else
+#ifdef	W32
+	snprintf(path, sizeof(path), "%s/%s", Audio::getCodecPath(), name);
+#else
 	snprintf(path, sizeof(path), "%s/%s", CODEC_LIBPATH, name);
+#endif
 #endif
 
 	return loadPlugin(path);
