@@ -101,9 +101,15 @@ AudioRegistry::AudioRegistry()
 
 	codecdir = "C:/Program Files/Common Files/CAPE Framework/Audio Codecs";
 
+#ifdef	DEBUG
+#define	PLUGINS "Debug"
+#else
+#define	PLUGINS "Codecs"
+#endif
+
 	if(RegOpenKey(HKEY_LOCAL_MACHINE, REGISTRY_AUDIO_SETTINGS, &key) == ERROR_SUCCESS)
 	{
-		if(RegQueryValue(key, "Codecs", regpath, &value) == ERROR_SUCCESS)
+		if(RegQueryValue(key, PLUGINS, regpath, &value) == ERROR_SUCCESS)
 		{
 			codecdir = regpath;
 			env = regpath;
