@@ -39,6 +39,8 @@
 #include "audio2.h"
 #include <cstdio>
 
+#define	MAX_DEVICES 1
+
 extern int _w32_ccaudio_dummy;
 int _w32_ccaudio_dummy = 0;
 
@@ -96,9 +98,12 @@ private:
 	volatile DWORD index, counter;
 
 	unsigned channels;
+	unsigned devid;
+
+	static W32AudioDevice *devices[MAX_DEVICES + 1];
 
 public:
-	W32AudioDevice();
+	W32AudioDevice(unsigned index);
 	~W32AudioDevice();
 
 	bool setAudio(Rate rate, bool stereo, timeout_t timeout);
@@ -112,9 +117,11 @@ public:
 	void flush(void);
 };
 
+W32AudioDevice *W32AudioDevice::devices[MAX_DEVICES + 1];
+
 static void CALLBACK playProc(HWAVEOUT hPlay, UINT msg, DWORD instance, DWORD p1, DWORD p2)
 {
-	W32AudioDevice *dev = (W32AudioDevice *)instance;
+	W32AudioDevice *dev = W32AudioDevice::devices[instance];
 	if(msg != WOM_DONE)
 		return;
 
@@ -125,13 +132,16 @@ static void CALLBACK playProc(HWAVEOUT hPlay, UINT msg, DWORD instance, DWORD p1
 	dev->sem->post();
 }
 
-W32AudioDevice::W32AudioDevice()
+W32AudioDevice::W32AudioDevice(unsigned index)
 {
 	headers = NULL;
 	buffers = NULL;
 	
 	enabled = false;
 	sem = NULL;
+
+	devid = index;
+	devices[index] = this;
 }
 
 W32AudioDevice::~W32AudioDevice()
@@ -241,7 +251,11 @@ bool W32AudioDevice::setAudio(Rate rate, bool stereo, timeout_t framing)
 
 	sem = new Semaphore(bufcount);
 
-	if(waveOutOpen(&hPlay, WAVE_MAPPER, &wfx, (DWORD)playProc, (DWORD)this, CALLBACK_FUNCTION) != MMSYSERR_NOERROR)
+#if !defined(_MSC_VER) || _MSC_VER < 1300
+#define DWORD_PTR DWORD
+#endif
+
+	if(waveOutOpen(&hPlay, WAVE_MAPPER, &wfx, (DWORD_PTR)&playProc, (DWORD)devid, CALLBACK_FUNCTION) != MMSYSERR_NOERROR)
 		return false;
 
 	enabled = true;
@@ -273,10 +287,10 @@ unsigned W32AudioDevice::putSamples(Linear samples, unsigned count)
 		{
 			memcpy(header->lpData + header->dwUser, data, size);
 			header->dwUser += size;
-			total += (size / scale);
+			total += (unsigned)(size / scale);
 			break;
 		}
-		fill = bufsize - header->dwUser;
+		fill = (unsigned)(bufsize - header->dwUser);
 		memcpy(header->lpData + header->dwUser, data, fill);
 		size -= fill;
 		data += fill;
@@ -309,13 +323,13 @@ AudioDevice *Audio::getDevice(unsigned index, DeviceMode mode)
 {
 	AudioDevice *dev;
 
-	if(index > 1)
+	if(index > MAX_DEVICES)
 		return NULL;
 
 	if(mode != PLAY)
 		return NULL;
 
-	dev = new W32AudioDevice();
+	dev = new W32AudioDevice(index);
 	dev->setAudio(rate8khz, false);
 	return dev;
 }
